# Supported LLM Providers 💪

The available API providers for LLMs are:

- [**Groq**](https://groq.com/) - more info about Groq models that can be used and how they can be used, can be found [here](https://docs.litellm.ai/docs/providers/groq)
- [**Mistral AI**](https://mistral.ai/) - more info about Mistral AI models that can be used and how they can be used, can be found [here](https://docs.litellm.ai/docs/providers/mistral-ai)
- [**Gemini**](https://gemini.google.com/) - more info about Gemini models that can be used and how they can be used, can be found [here](https://docs.litellm.ai/docs/providers/gemini)
- [**Bedrock**](https://aws.amazon.com/bedrock) - more info about Bedrock models that can be used and how they can be used, can be found [here](https://docs.litellm.ai/docs/providers/bedrock)
- [**Anthropic**](https://www.anthropic.com/) - more info about Anthropic models that can be used and how they can be used, can be found [here](https://docs.litellm.ai/docs/providers/anthropic)
- [**OpenAI**](https://openai.com) - more info about OpenAI models that can be used, and how they can be used, can be found [here](https://docs.litellm.ai/docs/providers/openai)
- [**Hugging Face**](https://huggingface.co/) - more info about Hugging Face models that can be used, and how they can be used, can be found [here](https://docs.litellm.ai/docs/providers/hugging-face)
- [**Ollama**](https://ollama.com/) - more info about Ollama models that can be used, and how they can be used, can be found [here](https://docs.litellm.ai/docs/providers/ollama)
- [**vLLM**](https://vllm.ai/) - more info about vLLM models that can be used and how they can be used, can be found [here](https://docs.litellm.ai/docs/providers/vllm)
- [**SageMaker**](https://aws.amazon.com/sagemaker/) - more info about SageMaker models that can be used and how they can be used, can be found [here](https://docs.litellm.ai/docs/providers/aws_sagemaker)
- [**Azure**](https://azure.microsoft.com/en-us/services/machine-learning/) - more info about Azure and Azure AI models that can be used and how they can be used, can be found [here](https://docs.litellm.ai/docs/providers/azure) & [here](https://docs.litellm.ai/docs/providers/azure_ai)
- [**Vertex AI**](https://cloud.google.com/vertex-ai) - more info about Vertex AI models that can be used and how they can be used, can be found [here](https://docs.litellm.ai/docs/providers/vertex)


